From e59e565936daec139bf836879cd99819f6f7d3dd Mon Sep 17 00:00:00 2001
From: Jonathan Fung
Date: Wed, 10 Apr 2024 16:50:50 -0400
Subject: [PATCH] proto bumps for query
---
.../src/codegen/dydxprotocol/clob/query.ts | 58 ++--
proto/dydxprotocol/clob/query.proto | 12 +-
protocol/x/clob/types/query.pb.go | 260 +++++++++---------
3 files changed, 165 insertions(+), 165 deletions(-)
diff --git a/protocol/x/clob/types/query.pb.go b/protocol/x/clob/types/query.pb.go
index 2b421428230..cfe13538cdf 100644
--- a/protocol/x/clob/types/query.pb.go
+++ b/protocol/x/clob/types/query.pb.go
@@ -919,8 +919,8 @@ func (m *StreamOrderbookUpdatesOrderPlacement) GetSnapshot() bool {
// StreamOrderbookUpdatesOrderFills contains updates for orderbook fills.
type StreamOrderbookUpdatesOrderFills struct {
- // List of clob matches with prices.
- Matches []ClobMatchWithPrices `protobuf:"bytes,1,rep,name=matches,proto3" json:"matches"`
+ // List of orderbook matches with prices.
+ Fills []OrderBookMatchFill `protobuf:"bytes,1,rep,name=fills,proto3" json:"fills"`
}
func (m *StreamOrderbookUpdatesOrderFills) Reset() { *m = StreamOrderbookUpdatesOrderFills{} }
@@ -956,39 +956,39 @@ func (m *StreamOrderbookUpdatesOrderFills) XXX_DiscardUnknown() {
var xxx_messageInfo_StreamOrderbookUpdatesOrderFills proto.InternalMessageInfo
-func (m *StreamOrderbookUpdatesOrderFills) GetMatches() []ClobMatchWithPrices {
+func (m *StreamOrderbookUpdatesOrderFills) GetFills() []OrderBookMatchFill {
if m != nil {
- return m.Matches
+ return m.Fills
}
return nil
}
-// ClobMatchWithPrices is a wrapper around the ClobMatch proto
+// OrderBookMatchFill is a wrapper around the ClobMatch proto
// that provides full `Order`s for all Order Ids involved in a ClobMatch.
// The Orders are used for price lookups.
-type ClobMatchWithPrices struct {
+type OrderBookMatchFill struct {
// Clob match. Note that the fill amounts here are delta
// fill amounts. The starting point for fill amounts have to be
// obtained from a `StreamOrderbookUpdatesOrderPlacement` OrderUpdate
// message exposing absolute fill amount.
- ClobMatches *ClobMatch `protobuf:"bytes,1,opt,name=clob_matches,json=clobMatches,proto3" json:"clob_matches,omitempty"`
- // All orders involved in clob_matches. Used to look up
+ ClobMatch *ClobMatch `protobuf:"bytes,1,opt,name=clob_match,json=clobMatch,proto3" json:"clob_match,omitempty"`
+ // All orders involved in the specified clob match. Used to look up
// price of a match through a given maker order id.
Orders []Order `protobuf:"bytes,2,rep,name=orders,proto3" json:"orders"`
}
-func (m *ClobMatchWithPrices) Reset() { *m = ClobMatchWithPrices{} }
-func (m *ClobMatchWithPrices) String() string { return proto.CompactTextString(m) }
-func (*ClobMatchWithPrices) ProtoMessage() {}
-func (*ClobMatchWithPrices) Descriptor() ([]byte, []int) {
+func (m *OrderBookMatchFill) Reset() { *m = OrderBookMatchFill{} }
+func (m *OrderBookMatchFill) String() string { return proto.CompactTextString(m) }
+func (*OrderBookMatchFill) ProtoMessage() {}
+func (*OrderBookMatchFill) Descriptor() ([]byte, []int) {
return fileDescriptor_3365c195b25c5bc0, []int{17}
}
-func (m *ClobMatchWithPrices) XXX_Unmarshal(b []byte) error {
+func (m *OrderBookMatchFill) XXX_Unmarshal(b []byte) error {
return m.Unmarshal(b)
}
-func (m *ClobMatchWithPrices) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
+func (m *OrderBookMatchFill) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
if deterministic {
- return xxx_messageInfo_ClobMatchWithPrices.Marshal(b, m, deterministic)
+ return xxx_messageInfo_OrderBookMatchFill.Marshal(b, m, deterministic)
} else {
b = b[:cap(b)]
n, err := m.MarshalToSizedBuffer(b)
@@ -998,26 +998,26 @@ func (m *ClobMatchWithPrices) XXX_Marshal(b []byte, deterministic bool) ([]byte,
return b[:n], nil
}
}
-func (m *ClobMatchWithPrices) XXX_Merge(src proto.Message) {
- xxx_messageInfo_ClobMatchWithPrices.Merge(m, src)
+func (m *OrderBookMatchFill) XXX_Merge(src proto.Message) {
+ xxx_messageInfo_OrderBookMatchFill.Merge(m, src)
}
-func (m *ClobMatchWithPrices) XXX_Size() int {
+func (m *OrderBookMatchFill) XXX_Size() int {
return m.Size()
}
-func (m *ClobMatchWithPrices) XXX_DiscardUnknown() {
- xxx_messageInfo_ClobMatchWithPrices.DiscardUnknown(m)
+func (m *OrderBookMatchFill) XXX_DiscardUnknown() {
+ xxx_messageInfo_OrderBookMatchFill.DiscardUnknown(m)
}
-var xxx_messageInfo_ClobMatchWithPrices proto.InternalMessageInfo
+var xxx_messageInfo_OrderBookMatchFill proto.InternalMessageInfo
-func (m *ClobMatchWithPrices) GetClobMatches() *ClobMatch {
+func (m *OrderBookMatchFill) GetClobMatch() *ClobMatch {
if m != nil {
- return m.ClobMatches
+ return m.ClobMatch
}
return nil
}
-func (m *ClobMatchWithPrices) GetOrders() []Order {
+func (m *OrderBookMatchFill) GetOrders() []Order {
if m != nil {
return m.Orders
}
@@ -1043,94 +1043,94 @@ func init() {
proto.RegisterType((*StreamOrderbookUpdate)(nil), "dydxprotocol.clob.StreamOrderbookUpdate")
proto.RegisterType((*StreamOrderbookUpdatesOrderPlacement)(nil), "dydxprotocol.clob.StreamOrderbookUpdatesOrderPlacement")
proto.RegisterType((*StreamOrderbookUpdatesOrderFills)(nil), "dydxprotocol.clob.StreamOrderbookUpdatesOrderFills")
- proto.RegisterType((*ClobMatchWithPrices)(nil), "dydxprotocol.clob.ClobMatchWithPrices")
+ proto.RegisterType((*OrderBookMatchFill)(nil), "dydxprotocol.clob.OrderBookMatchFill")
}
func init() { proto.RegisterFile("dydxprotocol/clob/query.proto", fileDescriptor_3365c195b25c5bc0) }
var fileDescriptor_3365c195b25c5bc0 = []byte{
- // 1293 bytes of a gzipped FileDescriptorProto
- 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x57, 0xcf, 0x6f, 0x1b, 0xc5,
- 0x17, 0xf7, 0x24, 0xfd, 0xb6, 0xc9, 0x4b, 0x5b, 0xf5, 0x3b, 0x69, 0x5a, 0xe3, 0xa4, 0x8e, 0xb3,
- 0x34, 0x89, 0x93, 0x8a, 0xdd, 0xfc, 0xa8, 0x4a, 0x49, 0x51, 0x51, 0x12, 0x91, 0x04, 0xa9, 0xa1,
- 0x66, 0x09, 0x29, 0x2a, 0x95, 0x56, 0xeb, 0xdd, 0xb1, 0x3d, 0x64, 0x77, 0xc7, 0xd9, 0x5d, 0x5b,
- 0x89, 0x10, 0x42, 0xe2, 0xc0, 0x05, 0x84, 0x90, 0x38, 0x70, 0x80, 0x1b, 0x37, 0x0e, 0xfc, 0x07,
- 0x08, 0xb8, 0xf5, 0x58, 0x89, 0x0b, 0x12, 0x08, 0xa1, 0x84, 0x33, 0x7f, 0x03, 0xda, 0xd9, 0x59,
- 0xc7, 0xce, 0xee, 0xda, 0x4e, 0x2e, 0x89, 0xe7, 0xcd, 0xe7, 0xbd, 0xf9, 0xbc, 0x37, 0x6f, 0xe6,
- 0x33, 0x0b, 0xb7, 0xcc, 0x43, 0xf3, 0xa0, 0xee, 0x32, 0x9f, 0x19, 0xcc, 0x52, 0x0c, 0x8b, 0x95,
- 0x95, 0xfd, 0x06, 0x71, 0x0f, 0x65, 0x6e, 0xc3, 0xff, 0x6f, 0x9f, 0x96, 0x83, 0xe9, 0xdc, 0xf5,
- 0x2a, 0xab, 0x32, 0x6e, 0x52, 0x82, 0x5f, 0x21, 0x30, 0x37, 0x51, 0x65, 0xac, 0x6a, 0x11, 0x45,
- 0xaf, 0x53, 0x45, 0x77, 0x1c, 0xe6, 0xeb, 0x3e, 0x65, 0x8e, 0x27, 0x66, 0xe7, 0x0d, 0xe6, 0xd9,
- 0xcc, 0x53, 0xca, 0xba, 0x47, 0xc2, 0xf8, 0x4a, 0x73, 0xb1, 0x4c, 0x7c, 0x7d, 0x51, 0xa9, 0xeb,
- 0x55, 0xea, 0x70, 0xb0, 0xc0, 0x2a, 0x71, 0x46, 0x65, 0x8b, 0x19, 0x7b, 0x9a, 0xab, 0xfb, 0x44,
- 0xb3, 0xa8, 0x4d, 0x7d, 0xcd, 0x60, 0x4e, 0x85, 0x56, 0x85, 0xc3, 0x54, 0xdc, 0x21, 0xf8, 0xa3,
- 0xd5, 0x75, 0xea, 0x0a, 0x48, 0x42, 0x96, 0xcc, 0x35, 0x49, 0x34, 0x3d, 0x19, 0x9f, 0xb6, 0x75,
- 0xdf, 0xa8, 0x91, 0x88, 0xff, 0x42, 0x1c, 0x40, 0xf6, 0x1b, 0xd4, 0x3f, 0xd4, 0x7c, 0x4a, 0xdc,
- 0x24, 0x52, 0x77, 0xe2, 0x1e, 0x16, 0xdd, 0x6f, 0x50, 0x33, 0xac, 0x4b, 0x27, 0x78, 0x3c, 0x61,
- 0x7d, 0xd2, 0x14, 0x93, 0x0f, 0x3b, 0x26, 0xa9, 0x63, 0x92, 0x03, 0xe2, 0x2a, 0xac, 0x52, 0xd1,
- 0x8c, 0x9a, 0x4e, 0x1d, 0xad, 0x51, 0x37, 0x75, 0x9f, 0x78, 0x71, 0x4b, 0xe8, 0x2f, 0xcd, 0xc1,
- 0xcd, 0x77, 0x82, 0x8a, 0x6f, 0x12, 0x7f, 0xdd, 0x62, 0xe5, 0x92, 0x4e, 0x5d, 0x95, 0xec, 0x37,
- 0x88, 0xe7, 0xe3, 0xab, 0x30, 0x40, 0xcd, 0x2c, 0x2a, 0xa0, 0xe2, 0x15, 0x75, 0x80, 0x9a, 0xd2,
- 0x13, 0x18, 0xe3, 0xd0, 0x13, 0x9c, 0x57, 0x67, 0x8e, 0x47, 0xf0, 0x43, 0x18, 0x6e, 0x95, 0x94,
- 0xe3, 0x47, 0x96, 0xc6, 0xe5, 0x58, 0x6b, 0xc8, 0x91, 0xdf, 0xda, 0x85, 0xe7, 0x7f, 0x4d, 0x66,
- 0xd4, 0x21, 0x43, 0x8c, 0x25, 0x5d, 0x70, 0x58, 0xb5, 0xac, 0xd3, 0x1c, 0x36, 0x00, 0x4e, 0x5a,
- 0x40, 0xc4, 0x9e, 0x91, 0xc3, 0x7e, 0x91, 0x83, 0x7e, 0x91, 0xc3, 0x7e, 0x14, 0xfd, 0x22, 0x97,
- 0xf4, 0x2a, 0x11, 0xbe, 0x6a, 0x9b, 0xa7, 0xf4, 0x3d, 0x82, 0x6c, 0x07, 0xf9, 0x55, 0xcb, 0x4a,
- 0xe3, 0x3f, 0x78, 0x46, 0xfe, 0x78, 0xb3, 0x83, 0xe4, 0x00, 0x27, 0x39, 0xdb, 0x93, 0x64, 0xb8,
- 0x78, 0x07, 0xcb, 0x3f, 0x11, 0x4c, 0x6e, 0x93, 0xe6, 0xdb, 0xcc, 0x24, 0x3b, 0x2c, 0xf8, 0xbb,
- 0xae, 0x5b, 0x46, 0xc3, 0xe2, 0x93, 0x51, 0x45, 0x9e, 0xc1, 0x8d, 0xb0, 0xe1, 0xeb, 0x2e, 0xab,
- 0x33, 0x8f, 0xb8, 0x9a, 0x68, 0xc6, 0x56, 0x75, 0xe2, 0xcc, 0x77, 0x75, 0x2b, 0x68, 0x2d, 0xe6,
- 0x6e, 0x93, 0xe6, 0x76, 0x88, 0x56, 0xaf, 0xf3, 0x28, 0x25, 0x11, 0x44, 0x58, 0xf1, 0x07, 0x30,
- 0xd6, 0x8c, 0xc0, 0x9a, 0x4d, 0x9a, 0x9a, 0x4d, 0x7c, 0x97, 0x1a, 0x5e, 0x2b, 0xab, 0x78, 0xf0,
- 0x0e, 0xc2, 0xdb, 0x21, 0x5c, 0x1d, 0x6d, 0xb6, 0x2f, 0x19, 0x1a, 0xa5, 0x7f, 0x11, 0x14, 0xd2,
- 0xd3, 0x13, 0x9b, 0x51, 0x85, 0x4b, 0x2e, 0xf1, 0x1a, 0x96, 0xef, 0x89, 0xad, 0xd8, 0xec, 0xb5,
- 0x66, 0x42, 0x94, 0x00, 0xb0, 0xea, 0x98, 0xbb, 0xcc, 0x6a, 0xd8, 0xa4, 0x44, 0xdc, 0x60, 0xeb,
- 0xc4, 0xb6, 0x45, 0xd1, 0x73, 0x3a, 0x8c, 0x26, 0xa0, 0x70, 0x01, 0x2e, 0xb7, 0x9a, 0x41, 0x6b,
- 0xf5, 0x3f, 0x44, 0x9b, 0xfd, 0x96, 0x89, 0xaf, 0xc1, 0xa0, 0x4d, 0x9a, 0xbc, 0x22, 0x03, 0x6a,
- 0xf0, 0x13, 0xdf, 0x80, 0x8b, 0x4d, 0x1e, 0x24, 0x3b, 0x58, 0x40, 0xc5, 0x0b, 0xaa, 0x18, 0x49,
- 0xf3, 0x50, 0xe4, 0x4d, 0xf7, 0x26, 0xbf, 0x0d, 0x76, 0x28, 0x71, 0x1f, 0x05, 0x77, 0xc1, 0x3a,
- 0x3f, 0xdd, 0x0d, 0xb7, 0x7d, 0x5f, 0xa5, 0x6f, 0x11, 0xcc, 0xf5, 0x01, 0x16, 0x55, 0x72, 0x20,
- 0x9b, 0x76, 0xc5, 0x88, 0x3e, 0x50, 0x12, 0xca, 0xd6, 0x2d, 0xb4, 0x28, 0xcf, 0x18, 0x49, 0xc2,
- 0x48, 0x73, 0x30, 0xcb, 0xc9, 0xad, 0x05, 0x4d, 0xa3, 0xea, 0x3e, 0x49, 0x4f, 0xe4, 0x1b, 0x24,
- 0xb2, 0xee, 0x8a, 0x15, 0x79, 0xec, 0xc1, 0xcd, 0x94, 0xeb, 0x5b, 0xa4, 0x21, 0x27, 0xa4, 0xd1,
- 0x25, 0xb0, 0xc8, 0x22, 0x6c, 0xee, 0x53, 0x10, 0x69, 0x16, 0xa6, 0x39, 0xb1, 0x47, 0x6d, 0x57,
- 0x6d, 0x62, 0x0a, 0x9f, 0x21, 0x98, 0xe9, 0x85, 0x14, 0x09, 0x3c, 0x83, 0xd1, 0x84, 0x9b, 0x5b,
- 0x90, 0x9f, 0x4e, 0x20, 0x1f, 0x0f, 0x29, 0x38, 0x63, 0x2b, 0x36, 0x23, 0xad, 0xc2, 0xad, 0x77,
- 0x7d, 0x97, 0xe8, 0xf6, 0xe3, 0x40, 0x8f, 0xca, 0x8c, 0xed, 0xbd, 0x17, 0xde, 0xde, 0xd1, 0x6d,
- 0x10, 0xef, 0xd6, 0xc1, 0xce, 0x6e, 0x95, 0x7e, 0x40, 0x90, 0x4f, 0x8b, 0x21, 0x72, 0xd8, 0x82,
- 0x4b, 0x42, 0x14, 0xc4, 0x91, 0x2b, 0x26, 0xf0, 0x4e, 0x8c, 0x11, 0x9d, 0x29, 0xe1, 0x8e, 0xa7,
- 0xe0, 0x72, 0xb8, 0x9d, 0x35, 0x42, 0xab, 0x35, 0x9f, 0x9f, 0x91, 0x2b, 0xea, 0x08, 0xb7, 0x6d,
- 0x71, 0x13, 0x1e, 0x87, 0x61, 0x72, 0x40, 0x0c, 0xcd, 0x66, 0x66, 0x78, 0x5c, 0xae, 0xa8, 0x43,
- 0x81, 0x61, 0x9b, 0x99, 0x44, 0xfa, 0x03, 0xc1, 0x58, 0xe2, 0x42, 0xf8, 0x29, 0x8c, 0x70, 0x4d,
- 0xd6, 0xea, 0x96, 0x6e, 0x10, 0x51, 0xdf, 0x57, 0xfb, 0xe5, 0xe9, 0xf1, 0x71, 0x29, 0x70, 0xb5,
- 0x89, 0xe3, 0x6f, 0x65, 0x54, 0x60, 0x2d, 0x0b, 0xde, 0x81, 0x70, 0xa4, 0x55, 0xa8, 0x65, 0x89,
- 0x9b, 0x6e, 0xf9, 0x6c, 0xa1, 0x37, 0xa8, 0x65, 0x79, 0x5b, 0x19, 0x75, 0x98, 0x45, 0xa3, 0xb5,
- 0x6b, 0x70, 0x35, 0x2c, 0x8b, 0x66, 0x13, 0xcf, 0xd3, 0xab, 0x44, 0xfa, 0x0e, 0xc1, 0xed, 0x7e,
- 0xe8, 0xe1, 0xf7, 0x4f, 0x6f, 0xc8, 0xfd, 0x4e, 0x36, 0x42, 0xe6, 0xe5, 0xb8, 0xa8, 0x3f, 0xae,
- 0x54, 0xd6, 0x03, 0x43, 0x18, 0x77, 0x77, 0xf1, 0xf4, 0x06, 0xe5, 0x60, 0xc8, 0x73, 0xf4, 0xba,
- 0x57, 0x63, 0xe1, 0xe6, 0x0c, 0xa9, 0xad, 0xb1, 0xf4, 0x21, 0x14, 0x7a, 0x65, 0x88, 0x37, 0xe0,
- 0xd2, 0x89, 0xdc, 0x0c, 0xa6, 0xc8, 0x4d, 0x70, 0x8f, 0x72, 0x41, 0x79, 0x42, 0xfd, 0x5a, 0xc9,
- 0xa5, 0x06, 0xf1, 0x22, 0x1e, 0xc2, 0x59, 0xfa, 0x12, 0xc1, 0x68, 0x02, 0x0c, 0xbf, 0x21, 0xfa,
- 0xb9, 0x53, 0xd3, 0x26, 0xba, 0x2d, 0xa2, 0x8e, 0x18, 0xd1, 0x4f, 0xe2, 0xe1, 0x7b, 0x70, 0x91,
- 0x6f, 0x41, 0xa0, 0x58, 0x01, 0xbf, 0x6c, 0x82, 0x2b, 0xcf, 0x47, 0x30, 0x12, 0xe8, 0xa5, 0x1f,
- 0x87, 0xe1, 0x7f, 0xfc, 0xc8, 0xe3, 0xcf, 0x11, 0x0c, 0x45, 0x52, 0x8f, 0xe7, 0x13, 0xdc, 0x53,
- 0xde, 0x4b, 0xb9, 0x62, 0x1a, 0xf6, 0xf4, 0x83, 0x49, 0x9a, 0xfb, 0xf4, 0xb7, 0x7f, 0xbe, 0x1e,
- 0x78, 0x19, 0x4f, 0x29, 0x5d, 0x1e, 0xa7, 0xca, 0x47, 0xd4, 0xfc, 0x18, 0x7f, 0x81, 0x60, 0xa4,
- 0xed, 0xcd, 0x92, 0x4e, 0x28, 0xfe, 0x78, 0xca, 0xdd, 0xe9, 0x45, 0xa8, 0xed, 0x11, 0x24, 0xdd,
- 0xe6, 0x9c, 0xf2, 0x78, 0xa2, 0x1b, 0x27, 0xfc, 0x33, 0x82, 0x6c, 0x9a, 0xf8, 0xe2, 0xa5, 0x33,
- 0x29, 0x75, 0xc8, 0x71, 0xf9, 0x1c, 0xea, 0x2e, 0xad, 0x70, 0xae, 0x77, 0x57, 0xd0, 0xbc, 0xa4,
- 0x28, 0x89, 0xaf, 0x63, 0xcd, 0x61, 0x26, 0xd1, 0x7c, 0x16, 0xfe, 0x37, 0xda, 0x48, 0xfe, 0x8a,
- 0x60, 0xa2, 0x9b, 0x0e, 0xe2, 0x07, 0x69, 0x55, 0xeb, 0x43, 0xc5, 0x73, 0xaf, 0x9f, 0xcf, 0x59,
- 0xe4, 0x35, 0xc3, 0xf3, 0x2a, 0xe0, 0xbc, 0xd2, 0xf5, 0x8b, 0x02, 0xff, 0x84, 0x60, 0xbc, 0x8b,
- 0x08, 0xe2, 0x95, 0x34, 0x16, 0xbd, 0xe5, 0x3b, 0xf7, 0xe0, 0x5c, 0xbe, 0x22, 0x81, 0x69, 0x9e,
- 0xc0, 0x24, 0xbe, 0xd5, 0xf5, 0x33, 0x0d, 0xff, 0x82, 0xe0, 0xa5, 0x54, 0x69, 0xc5, 0xf7, 0xd3,
- 0x18, 0xf4, 0xd2, 0xed, 0xdc, 0x6b, 0xe7, 0xf0, 0x14, 0xcc, 0x65, 0xce, 0xbc, 0x88, 0x67, 0x94,
- 0xbe, 0x3e, 0xcd, 0xf0, 0x27, 0x70, 0x23, 0xf9, 0xb2, 0xc4, 0x0b, 0x7d, 0x2b, 0x47, 0x44, 0x7b,
- 0xf1, 0x0c, 0x1e, 0x21, 0xdd, 0x05, 0xb4, 0x56, 0x7a, 0x7e, 0x94, 0x47, 0x2f, 0x8e, 0xf2, 0xe8,
- 0xef, 0xa3, 0x3c, 0xfa, 0xea, 0x38, 0x9f, 0x79, 0x71, 0x9c, 0xcf, 0xfc, 0x7e, 0x9c, 0xcf, 0x3c,
- 0xbd, 0x57, 0xa5, 0x7e, 0xad, 0x51, 0x96, 0x0d, 0x66, 0x77, 0x26, 0xd3, 0xbc, 0xfb, 0x0a, 0x57,
- 0x0b, 0xa5, 0x65, 0x39, 0x08, 0x13, 0xf4, 0x0f, 0xeb, 0xc4, 0x2b, 0x5f, 0xe4, 0xe6, 0xe5, 0xff,
- 0x02, 0x00, 0x00, 0xff, 0xff, 0x19, 0x91, 0x82, 0x85, 0xf5, 0x0f, 0x00, 0x00,
+ // 1289 bytes of a gzipped FileDescriptorProto
+ 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x57, 0xcf, 0x6f, 0xe3, 0xc4,
+ 0x17, 0xcf, 0xb4, 0xfb, 0xa3, 0x7d, 0xdd, 0x5d, 0xed, 0x77, 0xba, 0xed, 0xe6, 0x9b, 0xb6, 0x69,
+ 0x6a, 0xb6, 0x6d, 0xda, 0x15, 0x76, 0x7f, 0xac, 0x96, 0xa5, 0x45, 0x2b, 0xb5, 0x15, 0xdb, 0x22,
+ 0x6d, 0xd9, 0x60, 0x4a, 0x41, 0xcb, 0x4a, 0x96, 0x63, 0x4f, 0x12, 0xab, 0xb6, 0x27, 0xb5, 0x9d,
+ 0xa8, 0x15, 0x42, 0x48, 0x1c, 0x90, 0x10, 0x1c, 0x90, 0x38, 0x70, 0x80, 0x1b, 0x37, 0x0e, 0xfc,
+ 0x07, 0x08, 0xb8, 0xed, 0x71, 0x25, 0x2e, 0x48, 0x20, 0x84, 0x5a, 0xce, 0xfc, 0x0d, 0xc8, 0x33,
+ 0xe3, 0x6c, 0x52, 0xdb, 0x49, 0xda, 0x4b, 0xe2, 0x79, 0xf3, 0x79, 0xcf, 0x9f, 0xf7, 0xe6, 0xcd,
+ 0x7c, 0xc6, 0x30, 0x65, 0x1e, 0x9b, 0x47, 0x75, 0x8f, 0x06, 0xd4, 0xa0, 0xb6, 0x62, 0xd8, 0xb4,
+ 0xac, 0x1c, 0x36, 0x88, 0x77, 0x2c, 0x33, 0x1b, 0xfe, 0x5f, 0xfb, 0xb4, 0x1c, 0x4e, 0xe7, 0x6e,
+ 0x55, 0x69, 0x95, 0x32, 0x93, 0x12, 0x3e, 0x71, 0x60, 0x6e, 0xb2, 0x4a, 0x69, 0xd5, 0x26, 0x8a,
+ 0x5e, 0xb7, 0x14, 0xdd, 0x75, 0x69, 0xa0, 0x07, 0x16, 0x75, 0x7d, 0x31, 0xbb, 0x68, 0x50, 0xdf,
+ 0xa1, 0xbe, 0x52, 0xd6, 0x7d, 0xc2, 0xe3, 0x2b, 0xcd, 0xe5, 0x32, 0x09, 0xf4, 0x65, 0xa5, 0xae,
+ 0x57, 0x2d, 0x97, 0x81, 0x05, 0x56, 0x89, 0x33, 0x2a, 0xdb, 0xd4, 0x38, 0xd0, 0x3c, 0x3d, 0x20,
+ 0x9a, 0x6d, 0x39, 0x56, 0xa0, 0x19, 0xd4, 0xad, 0x58, 0x55, 0xe1, 0x30, 0x13, 0x77, 0x08, 0x7f,
+ 0xb4, 0xba, 0x6e, 0x79, 0x02, 0x92, 0x90, 0x25, 0xf5, 0x4c, 0x12, 0x4d, 0x4f, 0xc7, 0xa7, 0x1d,
+ 0x3d, 0x30, 0x6a, 0x24, 0xe2, 0xbf, 0x14, 0x07, 0x90, 0xc3, 0x86, 0x15, 0x1c, 0x6b, 0x81, 0x45,
+ 0xbc, 0x24, 0x52, 0x77, 0xe3, 0x1e, 0xb6, 0x75, 0xd8, 0xb0, 0x4c, 0x5e, 0x97, 0x4e, 0xf0, 0x44,
+ 0xc2, 0xfb, 0x49, 0x53, 0x4c, 0x3e, 0xec, 0x98, 0xb4, 0x5c, 0x93, 0x1c, 0x11, 0x4f, 0xa1, 0x95,
+ 0x8a, 0x66, 0xd4, 0x74, 0xcb, 0xd5, 0x1a, 0x75, 0x53, 0x0f, 0x88, 0x1f, 0xb7, 0x70, 0x7f, 0x69,
+ 0x01, 0x6e, 0xbf, 0x13, 0x56, 0x7c, 0x9b, 0x04, 0x5b, 0x36, 0x2d, 0x97, 0x74, 0xcb, 0x53, 0xc9,
+ 0x61, 0x83, 0xf8, 0x01, 0xbe, 0x01, 0x03, 0x96, 0x99, 0x45, 0x05, 0x54, 0xbc, 0xae, 0x0e, 0x58,
+ 0xa6, 0xf4, 0x3e, 0x8c, 0x31, 0xe8, 0x4b, 0x9c, 0x5f, 0xa7, 0xae, 0x4f, 0xf0, 0x43, 0x18, 0x6e,
+ 0x95, 0x94, 0xe1, 0x47, 0x56, 0x26, 0xe4, 0x58, 0x6b, 0xc8, 0x91, 0xdf, 0xe6, 0xa5, 0xe7, 0x7f,
+ 0x4d, 0x67, 0xd4, 0x21, 0x43, 0x8c, 0x25, 0x5d, 0x70, 0xd8, 0xb0, 0xed, 0xb3, 0x1c, 0x1e, 0x01,
+ 0xbc, 0x6c, 0x01, 0x11, 0x7b, 0x4e, 0xe6, 0xfd, 0x22, 0x87, 0xfd, 0x22, 0xf3, 0x7e, 0x14, 0xfd,
+ 0x22, 0x97, 0xf4, 0x2a, 0x11, 0xbe, 0x6a, 0x9b, 0xa7, 0xf4, 0x3d, 0x82, 0x6c, 0x07, 0xf9, 0x0d,
+ 0xdb, 0x4e, 0xe3, 0x3f, 0x78, 0x4e, 0xfe, 0x78, 0xbb, 0x83, 0xe4, 0x00, 0x23, 0x39, 0xdf, 0x93,
+ 0x24, 0x7f, 0x79, 0x07, 0xcb, 0x3f, 0x11, 0x4c, 0xef, 0x92, 0xe6, 0xdb, 0xd4, 0x24, 0x7b, 0x34,
+ 0xfc, 0xdd, 0xd2, 0x6d, 0xa3, 0x61, 0xb3, 0xc9, 0xa8, 0x22, 0xcf, 0x60, 0x9c, 0x37, 0x7c, 0xdd,
+ 0xa3, 0x75, 0xea, 0x13, 0x4f, 0x13, 0xcd, 0xd8, 0xaa, 0x4e, 0x9c, 0xf9, 0xbe, 0x6e, 0x87, 0xad,
+ 0x45, 0xbd, 0x5d, 0xd2, 0xdc, 0xe5, 0x68, 0xf5, 0x16, 0x8b, 0x52, 0x12, 0x41, 0x84, 0x15, 0x7f,
+ 0x08, 0x63, 0xcd, 0x08, 0xac, 0x39, 0xa4, 0xa9, 0x39, 0x24, 0xf0, 0x2c, 0xc3, 0x6f, 0x65, 0x15,
+ 0x0f, 0xde, 0x41, 0x78, 0x97, 0xc3, 0xd5, 0xd1, 0x66, 0xfb, 0x2b, 0xb9, 0x51, 0xfa, 0x17, 0x41,
+ 0x21, 0x3d, 0x3d, 0xb1, 0x18, 0x55, 0xb8, 0xea, 0x11, 0xbf, 0x61, 0x07, 0xbe, 0x58, 0x8a, 0xed,
+ 0x5e, 0xef, 0x4c, 0x88, 0x12, 0x02, 0x36, 0x5c, 0x73, 0x9f, 0xda, 0x0d, 0x87, 0x94, 0x88, 0x17,
+ 0x2e, 0x9d, 0x58, 0xb6, 0x28, 0x7a, 0x4e, 0x87, 0xd1, 0x04, 0x14, 0x2e, 0xc0, 0xb5, 0x56, 0x33,
+ 0x68, 0xad, 0xfe, 0x87, 0x68, 0xb1, 0xdf, 0x32, 0xf1, 0x4d, 0x18, 0x74, 0x48, 0x93, 0x55, 0x64,
+ 0x40, 0x0d, 0x1f, 0xf1, 0x38, 0x5c, 0x69, 0xb2, 0x20, 0xd9, 0xc1, 0x02, 0x2a, 0x5e, 0x52, 0xc5,
+ 0x48, 0x5a, 0x84, 0x22, 0x6b, 0xba, 0x37, 0xd9, 0x69, 0xb0, 0x67, 0x11, 0xef, 0x71, 0x78, 0x16,
+ 0x6c, 0xb1, 0xdd, 0xdd, 0xf0, 0xda, 0xd7, 0x55, 0xfa, 0x16, 0xc1, 0x42, 0x1f, 0x60, 0x51, 0x25,
+ 0x17, 0xb2, 0x69, 0x47, 0x8c, 0xe8, 0x03, 0x25, 0xa1, 0x6c, 0xdd, 0x42, 0x8b, 0xf2, 0x8c, 0x91,
+ 0x24, 0x8c, 0xb4, 0x00, 0xf3, 0x8c, 0xdc, 0x66, 0xd8, 0x34, 0xaa, 0x1e, 0x90, 0xf4, 0x44, 0xbe,
+ 0x41, 0x22, 0xeb, 0xae, 0x58, 0x91, 0xc7, 0x01, 0xdc, 0x4e, 0x39, 0xbe, 0x45, 0x1a, 0x72, 0x42,
+ 0x1a, 0x5d, 0x02, 0x8b, 0x2c, 0x78, 0x73, 0x9f, 0x81, 0x48, 0xf3, 0x30, 0xcb, 0x88, 0x3d, 0x6e,
+ 0x3b, 0x6a, 0x13, 0x53, 0xf8, 0x0c, 0xc1, 0x5c, 0x2f, 0xa4, 0x48, 0xe0, 0x19, 0x8c, 0x26, 0x9c,
+ 0xdc, 0x82, 0xfc, 0x6c, 0x02, 0xf9, 0x78, 0x48, 0xc1, 0x19, 0xdb, 0xb1, 0x19, 0x69, 0x03, 0xa6,
+ 0xde, 0x0d, 0x3c, 0xa2, 0x3b, 0x4f, 0x42, 0x3d, 0x2a, 0x53, 0x7a, 0xf0, 0x1e, 0x3f, 0xbd, 0xa3,
+ 0xd3, 0x20, 0xde, 0xad, 0x83, 0x9d, 0xdd, 0x2a, 0xfd, 0x80, 0x20, 0x9f, 0x16, 0x43, 0xe4, 0xb0,
+ 0x03, 0x57, 0x85, 0x28, 0x88, 0x2d, 0x57, 0x4c, 0xe0, 0x9d, 0x18, 0x23, 0xda, 0x53, 0xc2, 0x1d,
+ 0xcf, 0xc0, 0x35, 0xbe, 0x9c, 0x35, 0x62, 0x55, 0x6b, 0x01, 0xdb, 0x23, 0xd7, 0xd5, 0x11, 0x66,
+ 0xdb, 0x61, 0x26, 0x3c, 0x01, 0xc3, 0xe4, 0x88, 0x18, 0x9a, 0x43, 0x4d, 0xbe, 0x5d, 0xae, 0xab,
+ 0x43, 0xa1, 0x61, 0x97, 0x9a, 0x44, 0xfa, 0x03, 0xc1, 0x58, 0xe2, 0x8b, 0xf0, 0x53, 0x18, 0x61,
+ 0x9a, 0xac, 0xd5, 0x6d, 0xdd, 0x20, 0xa2, 0xbe, 0xaf, 0xf5, 0xcb, 0xd3, 0x67, 0xe3, 0x52, 0xe8,
+ 0xea, 0x10, 0x37, 0xd8, 0xc9, 0xa8, 0x40, 0x5b, 0x16, 0xbc, 0x07, 0x7c, 0xa4, 0x55, 0x2c, 0xdb,
+ 0x16, 0x27, 0xdd, 0xea, 0xf9, 0x42, 0x3f, 0xb2, 0x6c, 0xdb, 0xdf, 0xc9, 0xa8, 0xc3, 0x34, 0x1a,
+ 0x6d, 0xde, 0x84, 0x1b, 0xbc, 0x2c, 0x9a, 0x43, 0x7c, 0x5f, 0xaf, 0x12, 0xe9, 0x3b, 0x04, 0x77,
+ 0xfa, 0xa1, 0x87, 0x3f, 0x38, 0xbb, 0x20, 0x0f, 0x3a, 0xd9, 0x08, 0x99, 0x97, 0xe3, 0xa2, 0xfe,
+ 0xa4, 0x52, 0xd9, 0x0a, 0x0d, 0x3c, 0xee, 0xfe, 0xf2, 0xd9, 0x05, 0xca, 0xc1, 0x90, 0xef, 0xea,
+ 0x75, 0xbf, 0x46, 0xf9, 0xe2, 0x0c, 0xa9, 0xad, 0xb1, 0x44, 0xa0, 0xd0, 0x2b, 0x43, 0xbc, 0x01,
+ 0x97, 0xc3, 0x22, 0x45, 0xbc, 0x92, 0x1a, 0x9c, 0xa1, 0x37, 0x29, 0x3d, 0x60, 0x9a, 0xc2, 0x4a,
+ 0xc1, 0x49, 0x70, 0x4f, 0xe9, 0x73, 0x04, 0x38, 0x8e, 0xc1, 0xeb, 0xc0, 0xba, 0x96, 0xab, 0x99,
+ 0x58, 0xdf, 0xc9, 0x14, 0x15, 0x66, 0x5e, 0x2a, 0x13, 0x6d, 0xf6, 0x88, 0xef, 0xc3, 0x15, 0x56,
+ 0xf8, 0x50, 0xa7, 0x42, 0x5e, 0xd9, 0x54, 0x5e, 0x9c, 0x8a, 0x40, 0xaf, 0xfc, 0x38, 0x0c, 0x97,
+ 0xd9, 0x46, 0xc7, 0x5f, 0x20, 0x18, 0x8a, 0x04, 0x1e, 0x2f, 0x26, 0xb8, 0xa7, 0xdc, 0x92, 0x72,
+ 0xc5, 0x34, 0xec, 0xd9, 0x6b, 0x92, 0xb4, 0xf0, 0xe9, 0x6f, 0xff, 0x7c, 0x3d, 0xf0, 0x0a, 0x9e,
+ 0x51, 0xba, 0x5c, 0x49, 0x95, 0x8f, 0x2c, 0xf3, 0x63, 0xfc, 0x25, 0x82, 0x91, 0xb6, 0x9b, 0x4a,
+ 0x3a, 0xa1, 0xf8, 0x95, 0x29, 0x77, 0xb7, 0x17, 0xa1, 0xb6, 0xab, 0x8f, 0x74, 0x87, 0x71, 0xca,
+ 0xe3, 0xc9, 0x6e, 0x9c, 0xf0, 0xcf, 0x08, 0xb2, 0x69, 0x92, 0x8b, 0x57, 0xce, 0xa5, 0xcf, 0x9c,
+ 0xe3, 0xea, 0x05, 0x34, 0x5d, 0x5a, 0x63, 0x5c, 0xef, 0xad, 0xa1, 0x45, 0x49, 0x51, 0x12, 0xef,
+ 0xc4, 0x9a, 0x4b, 0x4d, 0xa2, 0x05, 0x94, 0xff, 0x1b, 0x6d, 0x24, 0x7f, 0x45, 0x30, 0xd9, 0x4d,
+ 0xfd, 0xf0, 0x7a, 0x5a, 0xd5, 0xfa, 0xd0, 0xee, 0xdc, 0x1b, 0x17, 0x73, 0x16, 0x79, 0xcd, 0xb1,
+ 0xbc, 0x0a, 0x38, 0xaf, 0x74, 0xfd, 0x8e, 0xc0, 0x3f, 0x21, 0x98, 0xe8, 0x22, 0x7d, 0x78, 0x2d,
+ 0x8d, 0x45, 0x6f, 0xd1, 0xce, 0xad, 0x5f, 0xc8, 0x57, 0x24, 0x30, 0xcb, 0x12, 0x98, 0xc6, 0x53,
+ 0x5d, 0x3f, 0xce, 0xf0, 0x2f, 0x08, 0xfe, 0x9f, 0x2a, 0xa8, 0xf8, 0x41, 0x1a, 0x83, 0x5e, 0x6a,
+ 0x9d, 0x7b, 0xfd, 0x02, 0x9e, 0x82, 0xb9, 0xcc, 0x98, 0x17, 0xf1, 0x9c, 0xd2, 0xd7, 0x07, 0x19,
+ 0xfe, 0x04, 0xc6, 0x93, 0x8f, 0x48, 0xbc, 0xd4, 0xb7, 0x5e, 0x44, 0xb4, 0x97, 0xcf, 0xe1, 0xc1,
+ 0xe9, 0x2e, 0xa1, 0xcd, 0xd2, 0xf3, 0x93, 0x3c, 0x7a, 0x71, 0x92, 0x47, 0x7f, 0x9f, 0xe4, 0xd1,
+ 0x57, 0xa7, 0xf9, 0xcc, 0x8b, 0xd3, 0x7c, 0xe6, 0xf7, 0xd3, 0x7c, 0xe6, 0xe9, 0xfd, 0xaa, 0x15,
+ 0xd4, 0x1a, 0x65, 0xd9, 0xa0, 0x4e, 0x67, 0x32, 0xcd, 0x7b, 0xaf, 0x32, 0x8d, 0x50, 0x5a, 0x96,
+ 0x23, 0x9e, 0x60, 0x70, 0x5c, 0x27, 0x7e, 0xf9, 0x0a, 0x33, 0xaf, 0xfe, 0x17, 0x00, 0x00, 0xff,
+ 0xff, 0xc2, 0x08, 0x77, 0x2f, 0xeb, 0x0f, 0x00, 0x00,
}
// Reference imports to suppress errors if they are not otherwise used.
@@ -2138,10 +2138,10 @@ func (m *StreamOrderbookUpdatesOrderFills) MarshalToSizedBuffer(dAtA []byte) (in
_ = i
var l int
_ = l
- if len(m.Matches) > 0 {
- for iNdEx := len(m.Matches) - 1; iNdEx >= 0; iNdEx-- {
+ if len(m.Fills) > 0 {
+ for iNdEx := len(m.Fills) - 1; iNdEx >= 0; iNdEx-- {
{
- size, err := m.Matches[iNdEx].MarshalToSizedBuffer(dAtA[:i])
+ size, err := m.Fills[iNdEx].MarshalToSizedBuffer(dAtA[:i])
if err != nil {
return 0, err
}
@@ -2155,7 +2155,7 @@ func (m *StreamOrderbookUpdatesOrderFills) MarshalToSizedBuffer(dAtA []byte) (in
return len(dAtA) - i, nil
}
-func (m *ClobMatchWithPrices) Marshal() (dAtA []byte, err error) {
+func (m *OrderBookMatchFill) Marshal() (dAtA []byte, err error) {
size := m.Size()
dAtA = make([]byte, size)
n, err := m.MarshalToSizedBuffer(dAtA[:size])
@@ -2165,12 +2165,12 @@ func (m *ClobMatchWithPrices) Marshal() (dAtA []byte, err error) {
return dAtA[:n], nil
}
-func (m *ClobMatchWithPrices) MarshalTo(dAtA []byte) (int, error) {
+func (m *OrderBookMatchFill) MarshalTo(dAtA []byte) (int, error) {
size := m.Size()
return m.MarshalToSizedBuffer(dAtA[:size])
}
-func (m *ClobMatchWithPrices) MarshalToSizedBuffer(dAtA []byte) (int, error) {
+func (m *OrderBookMatchFill) MarshalToSizedBuffer(dAtA []byte) (int, error) {
i := len(dAtA)
_ = i
var l int
@@ -2189,9 +2189,9 @@ func (m *ClobMatchWithPrices) MarshalToSizedBuffer(dAtA []byte) (int, error) {
dAtA[i] = 0x12
}
}
- if m.ClobMatches != nil {
+ if m.ClobMatch != nil {
{
- size, err := m.ClobMatches.MarshalToSizedBuffer(dAtA[:i])
+ size, err := m.ClobMatch.MarshalToSizedBuffer(dAtA[:i])
if err != nil {
return 0, err
}
@@ -2477,8 +2477,8 @@ func (m *StreamOrderbookUpdatesOrderFills) Size() (n int) {
}
var l int
_ = l
- if len(m.Matches) > 0 {
- for _, e := range m.Matches {
+ if len(m.Fills) > 0 {
+ for _, e := range m.Fills {
l = e.Size()
n += 1 + l + sovQuery(uint64(l))
}
@@ -2486,14 +2486,14 @@ func (m *StreamOrderbookUpdatesOrderFills) Size() (n int) {
return n
}
-func (m *ClobMatchWithPrices) Size() (n int) {
+func (m *OrderBookMatchFill) Size() (n int) {
if m == nil {
return 0
}
var l int
_ = l
- if m.ClobMatches != nil {
- l = m.ClobMatches.Size()
+ if m.ClobMatch != nil {
+ l = m.ClobMatch.Size()
n += 1 + l + sovQuery(uint64(l))
}
if len(m.Orders) > 0 {
@@ -4076,7 +4076,7 @@ func (m *StreamOrderbookUpdatesOrderFills) Unmarshal(dAtA []byte) error {
switch fieldNum {
case 1:
if wireType != 2 {
- return fmt.Errorf("proto: wrong wireType = %d for field Matches", wireType)
+ return fmt.Errorf("proto: wrong wireType = %d for field Fills", wireType)
}
var msglen int
for shift := uint(0); ; shift += 7 {
@@ -4103,8 +4103,8 @@ func (m *StreamOrderbookUpdatesOrderFills) Unmarshal(dAtA []byte) error {
if postIndex > l {
return io.ErrUnexpectedEOF
}
- m.Matches = append(m.Matches, ClobMatchWithPrices{})
- if err := m.Matches[len(m.Matches)-1].Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
+ m.Fills = append(m.Fills, OrderBookMatchFill{})
+ if err := m.Fills[len(m.Fills)-1].Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
return err
}
iNdEx = postIndex
@@ -4129,7 +4129,7 @@ func (m *StreamOrderbookUpdatesOrderFills) Unmarshal(dAtA []byte) error {
}
return nil
}
-func (m *ClobMatchWithPrices) Unmarshal(dAtA []byte) error {
+func (m *OrderBookMatchFill) Unmarshal(dAtA []byte) error {
l := len(dAtA)
iNdEx := 0
for iNdEx < l {
@@ -4152,15 +4152,15 @@ func (m *ClobMatchWithPrices) Unmarshal(dAtA []byte) error {
fieldNum := int32(wire >> 3)
wireType := int(wire & 0x7)
if wireType == 4 {
- return fmt.Errorf("proto: ClobMatchWithPrices: wiretype end group for non-group")
+ return fmt.Errorf("proto: OrderBookMatchFill: wiretype end group for non-group")
}
if fieldNum <= 0 {
- return fmt.Errorf("proto: ClobMatchWithPrices: illegal tag %d (wire type %d)", fieldNum, wire)
+ return fmt.Errorf("proto: OrderBookMatchFill: illegal tag %d (wire type %d)", fieldNum, wire)
}
switch fieldNum {
case 1:
if wireType != 2 {
- return fmt.Errorf("proto: wrong wireType = %d for field ClobMatches", wireType)
+ return fmt.Errorf("proto: wrong wireType = %d for field ClobMatch", wireType)
}
var msglen int
for shift := uint(0); ; shift += 7 {
@@ -4187,10 +4187,10 @@ func (m *ClobMatchWithPrices) Unmarshal(dAtA []byte) error {
if postIndex > l {
return io.ErrUnexpectedEOF
}
- if m.ClobMatches == nil {
- m.ClobMatches = &ClobMatch{}
+ if m.ClobMatch == nil {
+ m.ClobMatch = &ClobMatch{}
}
- if err := m.ClobMatches.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
+ if err := m.ClobMatch.Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
return err
}
iNdEx = postIndex
diff --git a/indexer/packages/v4-protos/src/codegen/dydxprotocol/clob/query.ts b/indexer/packages/v4-protos/src/codegen/dydxprotocol/clob/query.ts
index 8deccc61619..06563f4b34d 100644
--- a/indexer/packages/v4-protos/src/codegen/dydxprotocol/clob/query.ts
+++ b/indexer/packages/v4-protos/src/codegen/dydxprotocol/clob/query.ts
@@ -310,52 +310,52 @@ export interface StreamOrderbookUpdatesOrderPlacementSDKType {
/** StreamOrderbookUpdatesOrderFills contains updates for orderbook fills. */
export interface StreamOrderbookUpdatesOrderFills {
- /** List of clob matches with prices. */
- matches: ClobMatchWithPrices[];
+ /** List of orderbook matches with prices. */
+ fills: OrderBookMatchFill[];
}
/** StreamOrderbookUpdatesOrderFills contains updates for orderbook fills. */
export interface StreamOrderbookUpdatesOrderFillsSDKType {
- /** List of clob matches with prices. */
- matches: ClobMatchWithPricesSDKType[];
+ /** List of orderbook matches with prices. */
+ fills: OrderBookMatchFillSDKType[];
}
/**
* ClobMatchWithPrices is a wrapper around the ClobMatch proto
* that provides full `Order`s for all Order Ids involved in a ClobMatch.
* The Orders are used for price lookups.
*/
-export interface ClobMatchWithPrices {
+export interface OrderBookMatchFill {
/**
* Clob match. Note that the fill amounts here are delta
* fill amounts. The starting point for fill amounts have to be
* obtained from a `StreamOrderbookUpdatesOrderPlacement` OrderUpdate
* message exposing absolute fill amount.
*/
- clobMatches?: ClobMatch;
+ clobMatch?: ClobMatch;
/**
- * All orders involved in clob_matches. Used to look up
+ * All orders involved in the specified clob match. Used to look up
* price of a match through a given maker order id.
*/
orders: Order[];
}
/**
* ClobMatchWithPrices is a wrapper around the ClobMatch proto
* that provides full `Order`s for all Order Ids involved in a ClobMatch.
* The Orders are used for price lookups.
*/
-export interface ClobMatchWithPricesSDKType {
+export interface OrderBookMatchFillSDKType {
/**
* Clob match. Note that the fill amounts here are delta
* fill amounts. The starting point for fill amounts have to be
* obtained from a `StreamOrderbookUpdatesOrderPlacement` OrderUpdate
* message exposing absolute fill amount.
*/
- clob_matches?: ClobMatchSDKType;
+ clob_match?: ClobMatchSDKType;
/**
- * All orders involved in clob_matches. Used to look up
+ * All orders involved in the specified clob match. Used to look up
* price of a match through a given maker order id.
*/
@@ -1188,14 +1188,14 @@ export const StreamOrderbookUpdatesOrderPlacement = {
function createBaseStreamOrderbookUpdatesOrderFills(): StreamOrderbookUpdatesOrderFills {
return {
- matches: []
+ fills: []
};
}
export const StreamOrderbookUpdatesOrderFills = {
encode(message: StreamOrderbookUpdatesOrderFills, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
- for (const v of message.matches) {
- ClobMatchWithPrices.encode(v!, writer.uint32(10).fork()).ldelim();
+ for (const v of message.fills) {
+ OrderBookMatchFill.encode(v!, writer.uint32(10).fork()).ldelim();
}
return writer;
@@ -1211,7 +1211,7 @@ export const StreamOrderbookUpdatesOrderFills = {
switch (tag >>> 3) {
case 1:
- message.matches.push(ClobMatchWithPrices.decode(reader, reader.uint32()));
+ message.fills.push(OrderBookMatchFill.decode(reader, reader.uint32()));
break;
default:
@@ -1225,23 +1225,23 @@ export const StreamOrderbookUpdatesOrderFills = {
fromPartial(object: DeepPartial): StreamOrderbookUpdatesOrderFills {
const message = createBaseStreamOrderbookUpdatesOrderFills();
- message.matches = object.matches?.map(e => ClobMatchWithPrices.fromPartial(e)) || [];
+ message.fills = object.fills?.map(e => OrderBookMatchFill.fromPartial(e)) || [];
return message;
}
};
-function createBaseClobMatchWithPrices(): ClobMatchWithPrices {
+function createBaseOrderBookMatchFill(): OrderBookMatchFill {
return {
- clobMatches: undefined,
+ clobMatch: undefined,
orders: []
};
}
-export const ClobMatchWithPrices = {
- encode(message: ClobMatchWithPrices, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
- if (message.clobMatches !== undefined) {
- ClobMatch.encode(message.clobMatches, writer.uint32(10).fork()).ldelim();
+export const OrderBookMatchFill = {
+ encode(message: OrderBookMatchFill, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
+ if (message.clobMatch !== undefined) {
+ ClobMatch.encode(message.clobMatch, writer.uint32(10).fork()).ldelim();
}
for (const v of message.orders) {
@@ -1251,17 +1251,17 @@ export const ClobMatchWithPrices = {
return writer;
},
- decode(input: _m0.Reader | Uint8Array, length?: number): ClobMatchWithPrices {
+ decode(input: _m0.Reader | Uint8Array, length?: number): OrderBookMatchFill {
const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
let end = length === undefined ? reader.len : reader.pos + length;
- const message = createBaseClobMatchWithPrices();
+ const message = createBaseOrderBookMatchFill();
while (reader.pos < end) {
const tag = reader.uint32();
switch (tag >>> 3) {
case 1:
- message.clobMatches = ClobMatch.decode(reader, reader.uint32());
+ message.clobMatch = ClobMatch.decode(reader, reader.uint32());
break;
case 2:
@@ -1277,9 +1277,9 @@ export const ClobMatchWithPrices = {
return message;
},
- fromPartial(object: DeepPartial): ClobMatchWithPrices {
- const message = createBaseClobMatchWithPrices();
- message.clobMatches = object.clobMatches !== undefined && object.clobMatches !== null ? ClobMatch.fromPartial(object.clobMatches) : undefined;
+ fromPartial(object: DeepPartial): OrderBookMatchFill {
+ const message = createBaseOrderBookMatchFill();
+ message.clobMatch = object.clobMatch !== undefined && object.clobMatch !== null ? ClobMatch.fromPartial(object.clobMatch) : undefined;
message.orders = object.orders?.map(e => Order.fromPartial(e)) || [];
return message;
}
@@ -310,52 +310,52 @@ export interface StreamOrderbookUpdatesOrderPlacementSDKType {
}
/**
- * ClobMatchWithPrices is a wrapper around the ClobMatch proto
+ * OrderBookMatchFill is a wrapper around the ClobMatch proto
* that provides full `Order`s for all Order Ids involved in a ClobMatch.
* The Orders are used for price lookups.
@@ -310,52 +310,52 @@ export interface StreamOrderbookUpdatesOrderPlacementSDKType {
}
/**
- * ClobMatchWithPrices is a wrapper around the ClobMatch proto
+ * OrderBookMatchFill is a wrapper around the ClobMatch proto
* that provides full `Order`s for all Order Ids involved in a ClobMatch.
* The Orders are used for price lookups.
diff --git a/proto/dydxprotocol/clob/query.proto b/proto/dydxprotocol/clob/query.proto
index de4eb4a5264..6ea8ef2c38d 100644
--- a/proto/dydxprotocol/clob/query.proto
+++ b/proto/dydxprotocol/clob/query.proto
@@ -185,21 +185,21 @@ message StreamOrderbookUpdatesOrderPlacement {
// StreamOrderbookUpdatesOrderFills contains updates for orderbook fills.
message StreamOrderbookUpdatesOrderFills {
- // List of clob matches with prices.
- repeated ClobMatchWithPrices matches = 1 [ (gogoproto.nullable) = false ];
+ // List of orderbook matches with prices.
+ repeated OrderBookMatchFill fills = 1 [ (gogoproto.nullable) = false ];
}
// ClobMatchWithPrices is a wrapper around the ClobMatch proto
// that provides full `Order`s for all Order Ids involved in a ClobMatch.
// The Orders are used for price lookups.
-message ClobMatchWithPrices {
+message OrderBookMatchFill {
// Clob match. Note that the fill amounts here are delta
// fill amounts. The starting point for fill amounts have to be
// obtained from a `StreamOrderbookUpdatesOrderPlacement` OrderUpdate
// message exposing absolute fill amount.
- ClobMatch clob_matches = 1;
+ ClobMatch clob_match = 1;
- // All orders involved in clob_matches. Used to look up
+ // All orders involved in the specified clob match. Used to look up
// price of a match through a given maker order id.
repeated Order orders = 2 [ (gogoproto.nullable) = false ];
}
@@ -185,21 +185,21 @@ message StreamOrderbookUpdatesOrderPlacement {
}
-// ClobMatchWithPrices is a wrapper around the ClobMatch proto
+// OrderBookMatchFill is a wrapper around the ClobMatch proto
// that provides full `Order`s for all Order Ids involved in a ClobMatch.
// The Orders are used for price lookups.
\ No newline at end of file